AUDIT: r17841 - gnucash/trunk - Documentation: Fix a wide range of small mistakes in doxygen comments, including a few spots where .c and .h function declarations didn't agree on parameter names.

Charles Day cedayiv at cvs.gnucash.org
Thu Jan 22 16:14:08 EST 2009


Author: cedayiv
Date: 2009-01-22 16:14:08 -0500 (Thu, 22 Jan 2009)
New Revision: 17841
Trac: http://svn.gnucash.org/trac/changeset/17841

Modified:
   gnucash/trunk/lib/libqof/backend/file/qsf-xml.h
   gnucash/trunk/lib/libqof/qof/guid.c
   gnucash/trunk/src/backend/file/gnc-backend-file.c
   gnucash/trunk/src/backend/file/gnc-backend-file.h
   gnucash/trunk/src/backend/file/io-gncxml-v2.h
   gnucash/trunk/src/engine/FreqSpec.h
   gnucash/trunk/src/engine/Scrub.h
   gnucash/trunk/src/engine/Transaction.h
   gnucash/trunk/src/engine/gnc-commodity.h
   gnucash/trunk/src/gnome-utils/dialog-account.h
   gnucash/trunk/src/gnome-utils/dialog-commodity.h
   gnucash/trunk/src/gnome-utils/gnc-currency-edit.h
   gnucash/trunk/src/gnome-utils/gnc-embedded-window.h
   gnucash/trunk/src/gnome-utils/gnc-gnome-utils.h
   gnucash/trunk/src/gnome-utils/gnc-main-window.h
   gnucash/trunk/src/gnome-utils/gnc-plugin-file-history.c
   gnucash/trunk/src/gnome-utils/gnc-plugin-file-history.h
   gnucash/trunk/src/gnome-utils/gnc-plugin-page.h
   gnucash/trunk/src/gnome-utils/gnc-tree-model-account.h
   gnucash/trunk/src/gnome-utils/gnc-tree-view-account.c
   gnucash/trunk/src/gnome-utils/gnc-tree-view-account.h
   gnucash/trunk/src/gnome-utils/gnc-tree-view.c
   gnucash/trunk/src/gnome-utils/gnc-tree-view.h
   gnucash/trunk/src/gnome/dialog-progress.h
   gnucash/trunk/src/gnome/gnc-plugin-page-register.c
   gnucash/trunk/src/import-export/aqbanking/dialog-daterange.h
   gnucash/trunk/src/import-export/aqbanking/gnc-ab-getbalance.h
   gnucash/trunk/src/import-export/aqbanking/gnc-ab-gettrans.h
   gnucash/trunk/src/import-export/aqbanking/gnc-ab-trans-templ.h
   gnucash/trunk/src/import-export/aqbanking/gnc-file-aqb-import.h
   gnucash/trunk/src/import-export/import-backend.h
   gnucash/trunk/src/import-export/import-match-picker.h
   gnucash/trunk/src/register/ledger-core/split-register-layout.h
   gnucash/trunk/src/register/ledger-core/split-register.h
Log:
Documentation: Fix a wide range of small mistakes in doxygen comments, including a few spots where .c and .h function declarations didn't agree on parameter names.
BP


Modified: gnucash/trunk/lib/libqof/backend/file/qsf-xml.h
===================================================================
--- gnucash/trunk/lib/libqof/backend/file/qsf-xml.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/lib/libqof/backend/file/qsf-xml.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -612,8 +612,8 @@
 gboolean is_qsf_object_with_map_be(gchar *map_path, qsf_param *params);
 /** \brief Validate a QSF file and a selected QSF map
 
- at param	map_path	Absolute or relative path to the selected QSF map file
- at param	params	Pointer to qsf_param context
+ at param	path	Absolute or relative path to the selected QSF map file
+ at param	map_file	Name of the map file
 
 The file is validated against the QSF object schema, qsf-object.xsd.xml and
 each object described in the file is checked to find out if the supplied QSF

Modified: gnucash/trunk/lib/libqof/qof/guid.c
===================================================================
--- gnucash/trunk/lib/libqof/qof/guid.c	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/lib/libqof/qof/guid.c	2009-01-22 21:14:08 UTC (rev 17841)
@@ -65,9 +65,10 @@
 
 /**
  * gnc_value_get_guid
- * @value: a #GValue whose value we want to get.
  *
- * Returns: the value stored in @value.
+ * @param value a @c GValue whose value we want to get.
+ *
+ * @return the value stored in @a value
  */
 G_CONST_RETURN GUID*
 gnc_value_get_guid (const GValue *value)

Modified: gnucash/trunk/src/backend/file/gnc-backend-file.c
===================================================================
--- gnucash/trunk/src/backend/file/gnc-backend-file.c	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/backend/file/gnc-backend-file.c	2009-01-22 21:14:08 UTC (rev 17841)
@@ -1,5 +1,5 @@
 /********************************************************************
- * gnc-backend-xml.c: load and save data to XML files               *
+ * gnc-backend-file.c: load and save data to XML files              *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -18,7 +18,7 @@
  * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
  * Boston, MA  02110-1301,  USA       gnu at gnu.org                   *
 \********************************************************************/
-/** @file gnc-backend-xml.c
+/** @file gnc-backend-file.c
  *  @brief load and save data to XML files 
  *  @author Copyright (c) 2000 Gnumatic Inc.
  *  @author Copyright (c) 2002 Derek Atkins <warlord at MIT.EDU>

Modified: gnucash/trunk/src/backend/file/gnc-backend-file.h
===================================================================
--- gnucash/trunk/src/backend/file/gnc-backend-file.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/backend/file/gnc-backend-file.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -1,5 +1,5 @@
 /********************************************************************
- * gnc-backend-xml.h: load and save data to XML files               *
+ * gnc-backend-file.h: load and save data to XML files              *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *

Modified: gnucash/trunk/src/backend/file/io-gncxml-v2.h
===================================================================
--- gnucash/trunk/src/backend/file/io-gncxml-v2.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/backend/file/io-gncxml-v2.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -156,8 +156,8 @@
 } conv_type;
 
 /** Read a file as plain byte stream to find words that are not completely ASCII.
- * On error, @unique, @ambiguous and @impossible will be filled up to that point,
- * @error may contain an io channel error, -1 will be returned.
+ * On error, @a unique, @a ambiguous and @a impossible will be filled up to
+ * that point, -1 will be returned.
  *
  * @param filename Name of the file to read.
  *
@@ -174,8 +174,6 @@
  * @param impossible Location used for a list for undecodable byte sequences,
  * if not NULL.
  *
- * @param error Location to return an io channel error.
- *
  * @return Size of impossible, -1 on error.
  */
 gint gnc_xml2_find_ambiguous(

Modified: gnucash/trunk/src/engine/FreqSpec.h
===================================================================
--- gnucash/trunk/src/engine/FreqSpec.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/engine/FreqSpec.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -40,7 +40,8 @@
         _(MONTH_RELATIVE,) \
         _(COMPOSITE,)
 
-DEFINE_ENUM(FreqType, ENUM_LIST_TYPE) /**< \enum Frequency specification.
+DEFINE_ENUM(FreqType, ENUM_LIST_TYPE) /**< \enum FreqType
+Frequency specification.
 
 For BI_WEEKLY, use weekly[2] 
  SEMI_MONTHLY, use composite 

Modified: gnucash/trunk/src/engine/Scrub.h
===================================================================
--- gnucash/trunk/src/engine/Scrub.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/engine/Scrub.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -141,7 +141,7 @@
  *  out as part of the account.  Just in case anyone needs to fall
  *  back from CVS to a production version of code.
  *
- *  @param acc A pointer to the root account containing all
+ *  @param root A pointer to the root account containing all
  *  accounts in the current book.
  *
  *  @param table A pointer to the commodity table for the current

Modified: gnucash/trunk/src/engine/Transaction.h
===================================================================
--- gnucash/trunk/src/engine/Transaction.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/engine/Transaction.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -510,7 +510,7 @@
  *
  *  @param trans a Transaction that has been reversed
  *
- *  @param the transaction that reversed the given transaction, or
+ *  @return the transaction that reversed the given transaction, or
  *  NULL if the given transaction has not been reversed.
  */
 Transaction * xaccTransGetReversedBy(const Transaction *trans);

Modified: gnucash/trunk/src/engine/gnc-commodity.h
===================================================================
--- gnucash/trunk/src/engine/gnc-commodity.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/engine/gnc-commodity.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -838,6 +838,8 @@
  *
  *  @param namespace The new namespace to be added.
  *
+ *  @param book The book that the new namespace will belong to.
+ *
  *  @return A pointer to the newly created namespace. */
 gnc_commodity_namespace * gnc_commodity_table_add_namespace(gnc_commodity_table * table,
 							    const char * namespace,

Modified: gnucash/trunk/src/gnome/dialog-progress.h
===================================================================
--- gnucash/trunk/src/gnome/dialog-progress.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome/dialog-progress.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -24,15 +24,10 @@
 /** @addtogroup Dialogs
     @{ */
 /** @addtogroup ProgDialog Progress Dialog
-    @{ */
-/** @file dialog-progress.h
     @brief Dialog for displaying progress of long-running operations.
-    @author Copyright (C) 2000 Dave Peticolas
-    @author Copyright (C) 2008 Charles Day
-
-    These functions constitute an API for streamlining the creation
+    @details These functions constitute an API for streamlining the creation
     and management of progress dialogs. Once registered with the API,
-    the dialog's display and behavior can be controlled via simple API
+    the dialog's display and behavior can be controlled via simple
     calls that prevent the caller from needing to know anything about
     the underlying GUI.
 
@@ -42,6 +37,11 @@
     gnc_progress_dialog_custom(). This method allows custom-made dialogs
     to hand off the management of typical progress-related widgets, and
     allows long-running operations report progress in a standard way.
+    @{ */
+/** @file dialog-progress.h
+    @brief API for displaying progress of long-running operations.
+    @author Copyright (C) 2000 Dave Peticolas
+    @author Copyright (C) 2008 Charles Day
 */
 
 
@@ -124,7 +124,7 @@
  *
  *  @param progress a ::GNCProgressDialog
  *
- *  @param str the text to be displayed
+ *  @param heading the text to be displayed
  *
  * NOTE: For HIG-compliant dialogs, use gnc_progress_dialog_set_primary()
  * instead. */
@@ -196,8 +196,8 @@
 /** Show a Cancel button and set the Guile procedure that will be called
  *  when it is pressed by the user. It will be called after any C function
  *  registered with gnc_progress_dialog_set_cancel_func(). The procedure
- *  must return @c #t if the dialog should be hidden. If there is no C or Guile
- *  cancel callback (the default state), the Cancel button is hidden.
+ *  must return @c \#t if the dialog should be hidden. If there is no C or
+ *  Guile cancel callback (the default state), the Cancel button is hidden.
  *
  *  @param progress a ::GNCProgressDialog
  *

Modified: gnucash/trunk/src/gnome/gnc-plugin-page-register.c
===================================================================
--- gnucash/trunk/src/gnome/gnc-plugin-page-register.c	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome/gnc-plugin-page-register.c	2009-01-22 21:14:08 UTC (rev 17841)
@@ -1609,7 +1609,7 @@
  *  make a kind of sense, as radio buttons are nothing more than
  *  linked toggle buttons where only one can be active.
  *
- *  @param button The button whose state is changing.  This will be
+ *  @param radio The button whose state is changing.  This will be
  *  the previously selected button the first of the pair of calls to
  *  this function, and will be the newly selected button the second
  *  time.
@@ -1655,7 +1655,7 @@
  *  make a kind of sense, as radio buttons are nothing more than
  *  linked toggle buttons where only one can be active.
  *
- *  @param button The button whose state is changing.  This will be
+ *  @param radio The button whose state is changing.  This will be
  *  the previously selected button the first of the pair of calls to
  *  this function, and will be the newly selected button the second
  *  time.

Modified: gnucash/trunk/src/gnome-utils/dialog-account.h
===================================================================
--- gnucash/trunk/src/gnome-utils/dialog-account.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/dialog-account.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -70,7 +70,8 @@
  *  restrict the available account type values to the list specified
  *  by the caller.
  *
- *  @param unused This parameter is not used.
+ *  @param book The book in which the new account should be created.
+ *  This is a required argument.
  *
  *  @param valid_types A GList of GNCAccountType gints [as pointers]
  *  which are allowed to be created.  The calling function is

Modified: gnucash/trunk/src/gnome-utils/dialog-commodity.h
===================================================================
--- gnucash/trunk/src/gnome-utils/dialog-commodity.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/dialog-commodity.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -148,10 +148,6 @@
  *
  *  @param parent The parent window of the new dialog.
  *
- *  @param user_message A string that will be installed in the top of
- *  the dialog box as an instruction to the user.  If NULL, a generic
- *  instruction will be used.
- *
  *  @param cusip If present, this will be the default exchange
  *  specific data for the new commodity.
  *
@@ -177,7 +173,7 @@
 /** Ask the user to provide the information necessary to create a new
  *  commodity.
  *
- *  @param namespace If present, this will be the default namespace
+ *  @param default_namespace If present, this will be the default namespace
  *  for the new commodity.  This value will be ignored if it is the
  *  namespace for ISO 4217 currencies.
  *

Modified: gnucash/trunk/src/gnome-utils/gnc-currency-edit.h
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-currency-edit.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-currency-edit.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -99,7 +99,8 @@
  *  @param currency The currency to set as the displayed/selected
  *  value of the widget.
  */
-void gnc_currency_edit_set_currency (GNCCurrencyEdit *gce, const gnc_commodity *currency);
+void gnc_currency_edit_set_currency (GNCCurrencyEdit *gce,
+                                     const gnc_commodity *currency);
 
 
 /** Retrieve the displayed currency of the widget.

Modified: gnucash/trunk/src/gnome-utils/gnc-embedded-window.h
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-embedded-window.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-embedded-window.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -102,6 +102,8 @@
 
 /** Remove a data plugin page from a window.
  *
+ *  @param window The window whose plugin is to be removed.
+ *
  *  @param page The page of data to be removed. */
 void gnc_embedded_window_close_page (GncEmbeddedWindow *window,
 				     GncPluginPage *page);

Modified: gnucash/trunk/src/gnome-utils/gnc-gnome-utils.h
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-gnome-utils.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-gnome-utils.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -86,7 +86,7 @@
  *  with the given file domain.  This routine will display an error
  *  message if it can't find the file.
  *
- *  @param doamin The GnomeFileDomain, e.g. GNOME_FILE_DOMAIN_APP_HELP
+ *  @param domain The GnomeFileDomain, e.g. GNOME_FILE_DOMAIN_APP_HELP
  *
  *  @param name The name of the file to be found.
  *

Modified: gnucash/trunk/src/gnome-utils/gnc-main-window.h
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-main-window.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-main-window.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -309,11 +309,11 @@
 
 /**
  * gnc_gtk_action_group_set_translation_domain:
- * @action_group: a #GtkActionGroup
- * @domain: the translation domain to use for dgettext() calls
+ * @param action_group a #GtkActionGroup
+ * @param domain the translation domain to use for dgettext() calls
  * 
  * Sets the translation domain and uses dgettext() for translating the 
- * @label and @tooltip of #GtkActionEntry<!-- -->s added by 
+ * @a label and @a tooltip of #GtkActionEntry<!-- -->s added by 
  * gtk_action_group_add_actions().
  *
  * This is copied from gtk's gtk_action_group_set_translation_domain()
@@ -348,8 +348,6 @@
  *  page returns a failure indication, then the function stops walking
  *  pages and immediately returns a failure.
  *
- *  @param window Whe window whose pages should be checked.
- *
  *  @return FALSE if any page could not or would not comply, which
  *  should cancel the pending operation.  TRUE otherwise */
 gboolean gnc_main_window_all_finish_pending (void);

Modified: gnucash/trunk/src/gnome-utils/gnc-plugin-file-history.c
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-plugin-file-history.c	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-plugin-file-history.c	2009-01-22 21:14:08 UTC (rev 17841)
@@ -209,7 +209,7 @@
 /** Remove all occurences of a file name from the history list.  Move
  *  the other key values up in the list to fill the gaps.
  *
- *  @param filename The name of the file to remove from the list.
+ *  @param oldfile The name of the file to remove from the list.
  */
 void
 gnc_history_remove_file (const char *oldfile)

Modified: gnucash/trunk/src/gnome-utils/gnc-plugin-file-history.h
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-plugin-page.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-plugin-page.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -508,7 +508,7 @@
 
 /** Tell a page to finish any outstanding activities.
  *  
- *  @param page A page.
+ *  @param plugin_page A page.
  *
  *  @return FALSE if the page could not or would not comply, which
  *  should cancel the pending operation.  TRUE otherwise */

Modified: gnucash/trunk/src/gnome-utils/gnc-tree-model-account.h
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-tree-model-account.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-tree-model-account.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -122,7 +122,7 @@
 
 /** Create a new GtkTreeModel for manipulating gnucash accounts.
  *
- *  @param group The account group to put at the top level of the tree
+ *  @param root The account group to put at the top level of the tree
  *  hierarchy. */
 GtkTreeModel *gnc_tree_model_account_new (Account *root);
 /** @} */

Modified: gnucash/trunk/src/gnome-utils/gnc-tree-view-account.c
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-tree-view-account.c	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-tree-view-account.c	2009-01-22 21:14:08 UTC (rev 17841)
@@ -1698,7 +1698,7 @@
  *
  *  @param button The button that was clicked.
  *
- *  @param page A pointer to the account tree page to update. */
+ *  @param fd A pointer to the account filter dialog struct. */
 void
 gppat_filter_select_default_cb (GtkWidget *button,
 				AccountFilterDialog *fd)

Modified: gnucash/trunk/src/gnome-utils/gnc-tree-view-account.h
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-tree-view-account.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-tree-view-account.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -124,8 +124,7 @@
  *  but this code provides one so that it can be used with all parts
  *  of the gnucash gui.
  *
- *  @param group A list of the accounts to use as the first level of
- *  accounts in the created tree.  This list may not be NULL.
+ *  @param root The account to use as the first level of the created tree.
  *
  *  @param show_root Show the pseudo top-level account in this view.
  *

Modified: gnucash/trunk/src/gnome-utils/gnc-tree-view.c
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-tree-view.c	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-tree-view.c	2009-01-22 21:14:08 UTC (rev 17841)
@@ -488,7 +488,7 @@
  *
  *  @param view The visible tree widget.
  *
- *  @param id The "pref name" to find.
+ *  @param wanted The "pref name" to find.
  *
  */
 GtkTreeViewColumn *

Modified: gnucash/trunk/src/gnome-utils/gnc-tree-view.h
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-tree-view.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-tree-view.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -121,7 +121,7 @@
  *  will be displayed at all.  Use GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS
  *  if the checkbox should be displayed in all rows.
  *
- *  @param column_sort_function The function that GtkTreeModelSort
+ *  @param column_sort_fn The function that GtkTreeModelSort
  *  will call to compare two rows to determine their displayed order.
  *
  *  @param toggle_edited_cb The function to call when the user toggles
@@ -173,7 +173,7 @@
  *  will be displayed at all.  Use GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS
  *  if the checkbox should be displayed in all rows.
  *
- *  @param column_sort_function The function that GtkTreeModelSort
+ *  @param column_sort_fn The function that GtkTreeModelSort
  *  will call to compare two rows to determine their displayed
  *  order.
  *
@@ -243,7 +243,7 @@
  *  will be displayed at all.  Use GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS
  *  if the checkbox should be displayed in all rows.
  *
- *  @param column_sort_function The function that GtkTreeModelSort
+ *  @param column_sort_fn The function that GtkTreeModelSort
  *  will call to compare two rows to determine their displayed
  *  order.
  *
@@ -308,7 +308,7 @@
  *
  *  @param view The visible tree widget.
  *
- *  @param id The "pref name" to find.
+ *  @param wanted The "pref name" to find.
  *
  */
 GtkTreeViewColumn *

Modified: gnucash/trunk/src/import-export/aqbanking/dialog-daterange.h
===================================================================
--- gnucash/trunk/src/import-export/aqbanking/dialog-daterange.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/import-export/aqbanking/dialog-daterange.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -24,7 +24,7 @@
  * @{
  * @addtogroup AqBanking
  * @{
- * @file dialog-daterange.h
+ * @file aqbanking/dialog-daterange.h
  * @brief Dialog for date range entry
  * @author Copyright (C) 2002 Christian Stimming <stimming at tuhh.de>
  * @author Copyright (C) 2008 Andreas Koehler <andi5.py at gmx.net>
@@ -65,3 +65,5 @@
 G_END_DECLS
 
 #endif /* DIALOG_DATERANGE_H */
+/** @} */
+/** @} */

Modified: gnucash/trunk/src/import-export/aqbanking/gnc-ab-getbalance.h
===================================================================
--- gnucash/trunk/src/import-export/aqbanking/gnc-ab-getbalance.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/import-export/aqbanking/gnc-ab-getbalance.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -51,3 +51,5 @@
 G_END_DECLS
 
 #endif /* GNC_AB_GETBALANCE_H */
+/** @} */
+/** @} */

Modified: gnucash/trunk/src/import-export/aqbanking/gnc-ab-gettrans.h
===================================================================
--- gnucash/trunk/src/import-export/aqbanking/gnc-ab-gettrans.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/import-export/aqbanking/gnc-ab-gettrans.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -48,3 +48,5 @@
 G_END_DECLS
 
 #endif /* GNC_AB_GETTRANS_H */
+/** @} */
+/** @} */

Modified: gnucash/trunk/src/import-export/aqbanking/gnc-ab-trans-templ.h
===================================================================
--- gnucash/trunk/src/import-export/aqbanking/gnc-ab-trans-templ.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/import-export/aqbanking/gnc-ab-trans-templ.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -219,3 +219,5 @@
 G_END_DECLS
 
 #endif /* GNC_AB_TRANS_TEMPL_H */
+/** @} */
+/** @} */

Modified: gnucash/trunk/src/import-export/aqbanking/gnc-file-aqb-import.h
===================================================================
--- gnucash/trunk/src/import-export/aqbanking/gnc-file-aqb-import.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/import-export/aqbanking/gnc-file-aqb-import.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -24,7 +24,7 @@
  * @{
  * @addtogroup AqBanking
  * @{
- * @file gnc-file-aqb-import.h
+ * @file aqbanking/gnc-file-aqb-import.h
  * @brief DTAUS import module interface
  * @author Copyright (C) 2002 Benoit Grégoire <bock at step.polymtl.ca>
  * @author Copyright (C) 2008 Andreas Koehler <andi5.py at gmx.net>

Modified: gnucash/trunk/src/import-export/import-backend.h
===================================================================
--- gnucash/trunk/src/register/ledger-core/split-register-layout.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/register/ledger-core/split-register-layout.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -25,11 +25,12 @@
 
 #include "table-layout.h"
 #include "split-register.h"
-/** @addtogroup GUI
+/** @addtogroup Ledger
     @{ */
-/** @addtogroup Register Register visual layout.
-
- *  pick specific cell types to sit in specific columns, and add 
+/** @file split-register-layout.h
+ *  @brief Create the actual register visual layout
+ *  @author Copyright (C) 1998, 2004 Linas Vepstas <linas at linas.org>
+ *  Pick specific cell types to sit in specific columns, and add 
  *  connections so that user can tab from one field to the next.  
  *
  *  The actual layout depends on the register type, but, typically,
@@ -40,16 +41,10 @@
  *  original intent was that the layout would be fetched from a 
  *  config file that could be tweaked for a specific, non-GnuCash 
  *  application.
-    @{
- */
-/** @file split-register-layout.h
-    @brief Create the actual register visual layout
-    @author Copyright (C) 1998, 2004 Linas Vepstas <linas at linas.org>
 */
 
 /** Generate the split register layout. */
 TableLayout * gnc_split_register_layout_new (SplitRegister *reg);
 
 /** @} */
-/** @} */
 #endif

Modified: gnucash/trunk/src/register/ledger-core/split-register.h
===================================================================
--- gnucash/trunk/src/register/ledger-core/split-register.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/register/ledger-core/split-register.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -21,12 +21,8 @@
 \********************************************************************/
 /** @addtogroup GUI
 @{ */
-/** @addtogroup Ledger Checkbook Register Display Area
+/** @addtogroup Ledger Checkbook Register
 
-    @file split-register.h
-    @brief Checkbook Register Display Area
-    @author Copyright (C) 1998-2000 Linas Vepstas <linas at linas.org>
-
     The register is the spread-sheet-like area that looks like a 
     checkbook register.  It displays transactions, and allows the 
     user to edit transactions in-place.  The register does *not*
@@ -127,9 +123,15 @@
     have snuck in; these should also be cleaned up.
 */
 /** @{
+    @file split-register.h
+    @brief API for checkbook register display area
+    @author Copyright (C) 1998-2000 Linas Vepstas <linas at linas.org>
 
 */
+/** @{
 
+*/
+
 #ifndef SPLIT_REGISTER_H
 #define SPLIT_REGISTER_H
 
@@ -436,6 +438,7 @@
 
 /** @} */
 /** @} */
+/** @} */
 /* -------------------------------------------------------------- */
 
 /** Private function -- outsiders must not use this */



More information about the gnucash-changes mailing list
--- gnucash/trunk/src/gnome-utils/gnc-plugin-file-history.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/gnome-utils/gnc-plugin-file-history.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -96,9 +96,9 @@
 /** Remove all occurences of a file name from the history list.  Move
  *  the other key values up in the list to fill the gaps.
  *
  *  @param filename The name of the file to remove from the list.
  */
-void gnc_history_remove_file (const char *filename);
+void gnc_history_remove_file (const char *oldfile);
 
 
 /** Retrieve the name of the file most recently accessed.  This is the
@@ -96,9 +96,9 @@
  *  the other key values up in the list to fill the gaps.
  *
- *  @param filename The name of the file to remove from the list.
+ *  @param oldfile The name of the file to remove from the list.
  */

Modified: gnucash/trunk/src/gnome-utils/gnc-plugin-page.h
===================================================================
--- gnucash/trunk/src/import-export/import-backend.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/import-export/import-backend.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -62,7 +62,7 @@
  * transaction, find all matching splits there, and store them in the
  * GNCImportTransInfo structure.
  *
  * @param transaction_info The TransInfo for which the corresponding
  * matching existing transactions should be found.
  *
  * @param process_threshold Each match whose heuristics are smaller
@@ -82,7 +82,7 @@
  * with paper checks (e.g. OFX, QIF), values like 42 (days) seem more
  * appropriate. 
  */
-void gnc_import_find_split_matches(GNCImportTransInfo *transaction_info,
+void gnc_import_find_split_matches(GNCImportTransInfo *trans_info,
 				   gint process_threshold, 
 				   double fuzzy_amount_difference,
 				   gint match_date_hardlimit);
@@ -62,7 +62,7 @@
  * GNCImportTransInfo structure.
  *
- * @param transaction_info The TransInfo for which the corresponding
+ * @param trans_info The TransInfo for which the corresponding
  * matching existing transactions should be found.
  *

Modified: gnucash/trunk/src/import-export/import-match-picker.h
===================================================================
--- gnucash/trunk/src/import-export/import-match-picker.h	2009-01-21 18:58:21 UTC (rev 17840)
+++ gnucash/trunk/src/import-export/import-match-picker.h	2009-01-22 21:14:08 UTC (rev 17841)
@@ -47,10 +47,10 @@
  *
  * This function is used from the gnc-gen-transaction code.
  *
  * @param trans_info The TransInfo for which the user is supposed to
  * pick a matching transaction. */
 void 
-gnc_import_match_picker_run_and_close (GNCImportTransInfo *trans_info);
+gnc_import_match_picker_run_and_close (GNCImportTransInfo *transaction_info);
 /**@}*/
 
 
@@ -47,10 +47,10 @@
  * This function is used from the gnc-gen-transaction code.
  *
- * @param trans_info The TransInfo for which the user is supposed to
+ * @param transaction_info The TransInfo for which the user is supposed to
  * pick a matching transaction. */
 void 

Modified: gnucash/trunk/src/register/ledger-core/split-register-layout.h
===================================================================